 /*+-------------------------------------------------------------+
   |          S A S   S A M P L E   L I B R A R Y                |
   |                                                             |
   |    NAME: GEOWCITY                                           |
   |   TITLE: GEOWCITY- World City Geocoding                     |
   | PRODUCT: GRAPH                                              |
   |  SYSTEM: ALL                                                |
   |    KEYS: GRAPHICS MAPS GEOCODE                              |
   |   PROCS: GEOCODE                                            |
   |    DATA: EXTERNAL                                           |
   |                                                             |
   | SUPPORT: GRAPHICS STAFF              CREATED: 04MAR2015     |
   |  UPDATE: 04MAR2015 - removed quit per customer request      |
   |     REF: SAS/GRAPH AND BASE SAS MAPPING REFERENCE           |
   +-------------------------------------------------------------+*/

/* Generate the CITIES input data set that the GEOCODE procedure
   uses. */
data cities (label='International cities');
  infile datalines dlm=',';
  length city $32 province $24 countryID $3;
  input city        /* City name                    */
        province    /* State/province/district name */
        countryID;  /* Three-character country code */
datalines;
Bella Vista, , ARG
Bella Vista, Corrientes, ARG
Adelaide, , AUS
Quebec, Quebec, CAN
Shanghai, , CHN
Skanderborg, , DNK
Barcelona, , ESP
Tallinn, , EST
Glasgow, , GBR
Pune, , IND
Dublin, , IRL
Seoul, , KOR
Luxembourg, , LUX
Vilnius, , LTU
Garza Garcia, , MEX
Bratislava, , SVK
Stockholm, , SWE
Bangkok, , THA
Houston, Texas, USA
Johannesburg, , ZAF
;
run;

/* Run the GEOCODE procedure with the generated CITIES input data set.
   Specify that GEOCODE use the city method. When geocoding international
   cities, you are required to use the ADDRESSCOUNTRYVAR= option to
   indicate that the cities are not all within the United States. Because
   the LOOKUPCITY= data set option is omitted, the GEOCODE procedure uses
   the default world lookup data set MAPSGFK.WORLD_CITIES. The procedure
   produces the GEOCODED_CITIES output data set. The output data set
   contains the LAT and LONG coordinate variables from the lookup data
   set. */
proc geocode                           /* Invoke geocoding procedure            */ 
   method=city                         /* Specify geocoding method              */
   data=cities                         /* Input data set of cities              */
   out=geocoded_cities                 /* Output data set of locations          */
   addresscityvar=city                 /* City name                             */
   addresscountryvar=countryID         /* Required for international geocoding  */
   addressstatevar=province            /* Optional state/province/district name */
   attributevar=(isoname mapidname1);  /* Values to assign to geocoded cities   */
run;

/* Print the entire GEOCODED_CITIES output data set, suppressing 
   the observation column. */
proc print data=geocoded_cities noobs;
run;
