 /*+-------------------------------------------------------------+
   |          S A S   S A M P L E   L I B R A R Y                |
   |                                                             |
   |    NAME: GANGCITY                                           |
   |   TITLE: GANGCITY-Labeling Cities on a Map                  |
   | PRODUCT: GRAPH                                              |
   |  SYSTEM: ALL                                                |
   |    KEYS: GRAPHICS ANNOTATE PATTERN GMAP                     |
   |   PROCS: GMAP                                               |
   |    DATA: INTERNAL                                           |
   |                                                             |
   | SUPPORT: GRAPHICS STAFF                                     |             
   |  UPDATE: 01JUL2008                                          |
   |          24OCT2016                                          |
   |          18APR2019 - used GfK data set in 2nd DATA step     |
   |     REF: SAS/GRAPH AND BASE SAS MAPPING REFERENCE           |
   +-------------------------------------------------------------+*/

/* Set the graphics environment. */
goptions border;

/* Subset the U.S. map data set by omitting Alaska, Hawaii, and
   Puerto Rico. */
data lower48;
   set mapsgfk.us;
   if state ne stfips("AK");
   if state ne stfips("HI");
   if state ne stfips("PR");
run;

/* Create the Annotate data set, CITYSTAR. */
data citystar;
   length function style color $ 8 position $ 1
          text $ 20;
   retain xsys ysys "2" hsys "3"
          when "a";
          
/* Include the values of selected variables from MAPSGFK.USCITY. */
   set mapsgfk.uscity(keep=x y city state);
       if (city="Atlanta" and state=13)
       or (city="Chicago" and state=17)
       or (city="Seattle" and state=53);

/* Create the observation that draws the star. */
   function="symbol"; style="marker"; text="V"; color="red"; size=5;
      output;

/* Create the observation that labels the city. */
   function="label"; style=""; text=city; color="green";
      size=5; position="8"; output;
run;

/* Define the title for the map. */
title "Distribution Center Locations";

/* Define patterns for the map areas. */
pattern value=mempty color=blue repeat=49;

/* Generate the map and assign the annotate data set to the CHORO
   statement. */
proc gmap data=lower48 map=lower48;
   id state;
   choro state / statistic=freq annotate=citystar discrete nolegend;
run;
quit;

/* Reset the graphics environment. */
goptions reset=all;
