  /*+----------------------------------------------------------------------+
   |          S A S   S A M P L E   L I B R A R Y                         |
   |                                                                      |
   |    NAME: GMPGCONC                                                    |
   |   TITLE: GMPGCONC- Producing a Choropleth Map By Combining Three Map |
   |          Data Sets                                                   |
   | PRODUCT: GRAPH                                                       |
   |  SYSTEM: ALL                                                         |
   |    KEYS: GRAPHICS MAPS GMAP CHORO STATISTIC                          |
   |   PROCS: GMAP                                                        |
   |    DATA: INTERNAL                                                    |
   |                                                                      |
   | SUPPORT: GRAPHICS STAFF                           CREATED: 27JUL2012 |
   |     REF: SAS/GRAPH AND BASE SAS MAPPING REFERENCE                    |
   +----------------------------------------------------------------------+*/

/* Set the graphics environment. */
goptions reset=all border device=png;

/* Specify the countries to combine. */
data all;
length name $18;
set mapsgfk.austria(in=k1) mapsgfk.czech_republic(in=k2) mapsgfk.hungary;

if k1 then name='Austria';
else if k2 then name='Czech Republic';
else name='Hungary';
x=long;
y=lat;
run;

/* Project the map and store the projection parameters. */
proc gproject data=all out=map degrees eastlong parmout;
id name id;
run;

/* Define the title, footnote, and legend for the map. */
title1 "Combining 3 Map Data Sets"; 
footnote j=r "This map was drawn using GfK map data.";
legend1 label=("Country Name:");

/* Produce the choropleth map that combines 3 European countries. */
proc gmap map=map data=map;
id name id; 
choro name/discrete stat=first legend=legend1;
run;
quit;

/* Reset the graphics environment. */
goptions reset=all;
