 /*+-------------------------------------------------------------+
   |          S A S   S A M P L E   L I B R A R Y                |
   |                                                             |
   |    NAME: GMPGLABL                                           |
   |   TITLE: GMPGLABL-Labeling Provinces on a Map               |
   | PRODUCT: GRAPH                                              |
   |  SYSTEM: ALL                                                |
   |    KEYS: GRAPHICS MAPS GMAP ANNOTATE                        |
   |   PROCS: GMAP                                               |
   |    DATA: INTERNAL                                           |
   |                                                             |
   | SUPPORT: GRAPHICS STAFF                                     |
   |  UPDATE: 06MAR2013 - Increased size of annotated text       |
   |            (province labels)                                |
   |          17APR2019 - Changed MAPLABEL verbiage              |
   |     REF: SAS/GRAPH AND BASE SAS MAPPING REFERENCE           |
   +-------------------------------------------------------------+*/

/* Set the graphics environment. */
goptions border;

/* Define the title for the map. */
title "Labeling Provinces with the MAPLABEL Macro";

/* Sort the GfK data by region and district variables. */
proc sort data=mapsgfk.belarus out=belarus;
by id1 id; 
run;

/* Use the GREMOVE procedure to remove the internal boundaries
   from the Belarus map. */
proc gremove data=belarus out=belarus_outline;
by id1;
id id;
run;

/* Create the Annotate data set. */
%annomac;
%maplabel (belarus_outline, mapsgfk.belarus_attr, work.labelout, id1name, id1,
           font=Albany AMT/bold, color=black, size=3, hsys=3);
           
/* Specify colors for the map. */
pattern1 c=lightblue;
pattern2 c=lightcyan;
pattern3 c=lightpink;
pattern4 c=lightgreen;
pattern5 c=lightbrown;
pattern6 c=lightyellow;
pattern7 c=lightgrey;

/* Produce the choropleth map. */
proc gmap map=belarus data=belarus;
   id id1 id;
   choro id1 / nolegend annotate=labelout coutline=gray stat=first;
run;
quit;

/* Reset the graphics environment. */
goptions reset=all;
