 /*+-------------------------------------------------------------+
   |          S A S   S A M P L E   L I B R A R Y                |
   |                                                             |
   |    NAME: GMPGLEVL                                           |
   |   TITLE: GMPGLEVL-Specifying Response Levels in a Block Map |
   | PRODUCT: GRAPH                                              |
   |  SYSTEM: ALL                                                |
   |    KEYS: GRAPHICS MAPS GMAP PATTERN  LEGEND                 |
   |   PROCS: GMAP                                               |
   |    DATA: INTERNAL                                           |
   |  UPDATE: 04MAR2013                                          |
   |          17APR2019 - Changed 'Create a table' verbiage      |
   | SUPPORT: GRAPHICS STAFF                                     |
   |     REF: SAS/GRAPH AND BASE SAS REFERENCE GUIDE             |
   +-------------------------------------------------------------+*/

/* Set the graphics environment. */
goptions reset=all border device=png;

/* Specify the format catalog to search that has the predefined
   ISO alpha2 code. */
%let originalfmtsearch = %sysfunc(getoption(fmtsearch,keyword));
options insert=(fmtsearch=(sashelp.mapfmts));

/* Create a table named demographics using sashelp.demographics as
   the base and change its variables to match GfK variable types
   and lengths. This table is used as the response data set. */
proc sql;
create table demographics(rename=(iso=oiso newiso=iso id=oldid newid=ID)) as
select demo.*, 
put(demo.iso,z3.) as newiso format=$3.,
put(demo.iso,ison2a.) as newid 
from sashelp.demographics as demo
;
alter table demographics
modify ID char(15) label='Alpha2 Country Code';
quit;

/* Define the titles, footnote, and color for the map. */
title1 "Gross National Income per Capita";
title2 "South America";
footnote1 j=r "This map was drawn using GfK map data.";
pattern1 value=msolid color=tan;

/* Produce the block map. */
proc gmap data=demographics(where=(cont=92))
map=mapsgfk.samerica all;
id iso;
block gni / levels=3 shape=prism
            relzero cempty=gray;
run;
quit;

/* Reset the graphics environment. */
goptions reset=all;

/* Restore the original FMTSEARCH system option value. */
options &originalfmtsearch;
