/*+---------------------------------------------------------------+
   |          S A S   S A M P L E   L I B R A R Y                 |
   |                                                              |
   |    NAME: GMPGSIMP                                            |
   |   TITLE: GMPGSIMP-Producing a Simple Block Map               |
   | PRODUCT: GRAPH                                               |
   |  SYSTEM: ALL                                                 |
   |    KEYS: GRAPHICS MAPS GMAP RESOLUTION LEGEND MAPSGFK PATTERN|
   |   PROCS: GMAP                                                |
   |    DATA: INTERNAL                                            |
   |                                                              |
   | SUPPORT: GRAPHICS STAFF              CREATED: 25JUL2012      |
   | UPDATED: 04MAR2013                                           |
   |            - RESOLUTION= option replaced where clause with   |
   |              resolution variable.                            |
   |            - Added LEGEND statement.                         |
   |            - PATTERN statement added to make map color       |
   |              different                                       |
   |          17APR2019                                           |
   |            - Changed 'Create a table' verbiage               |
   |            - Changed code to use a gray map outline          |
   |     REF: SAS/GRAPH AND BASE SAS REFERENCE                    |
   +--------------------------------------------------------------+*/

/* Set the graphics environment. */
goptions reset=all border device=png;

/* Specify the format catalog to search that has the predefined
   ISO alpha2 code. */
%let originalfmtsearch = %sysfunc(getoption(fmtsearch,keyword));
options insert=(fmtsearch=(sashelp.mapfmts));

/* Create a table named demographics using sashelp.demographics as
   the base and change its variables to match GfK variable types and
   lengths. This table is used as the response data set. */
proc sql; 
create table demographics(rename=(iso=oiso newiso=iso id=oldid newid=ID)) as
select demo.*, 
put(demo.iso,z3.) as newiso format=$3.,
put(demo.iso,ison2a.) as newid 
from sashelp.demographics as demo
;
alter table demographics
modify ID char(15) label='Alpha2 Country Code';
quit;

/* Define the title, legend, footnote, and color for the map. */
title1 "Population in Asia";
legend1 label=(position=top) shape=bar(.3in,.1in);
footnote1 j=r "This map was drawn using GfK map data.";
pattern1 value=msolid color=tan;

/* Produce the block map. */
proc gmap data=demographics(where=(cont=95))
           map=mapsgfk.asia resolution=4 all;
   id iso;
   block pop / blocksize=1 relzero coutline=gray legend=legend1;
run;
quit;

/* Reset the graphics environment. */
goptions reset=all;

/* Restore the original FMTSEARCH system option value. */
options &originalfmtsearch;
