 /*+-------------------------------------------------------------+
   |          S A S   S A M P L E   L I B R A R Y                |
   |                                                             |
   |    NAME: GMPGSURF                                           |
   |   TITLE: GMPGSURF- Producing a Simple Surface Map           |
   | PRODUCT: GRAPH                                              |
   |  SYSTEM: ALL                                                |
   |    KEYS: GRAPHICS MAPS GMAP                                 |
   |   PROCS: GMAP                                               |
   |    DATA: INTERNAL                                           |
   |                                                             |
   | SUPPORT: GRAPHICS STAFF                                     |             
   |  UPDATE: 08MAR2013 - Switched map from Europe to South      |
   |             America                                         |
   |     REF: SAS/GRAPH AND BASE SAS MAPPING REFERENCE GUIDE     |
   +-------------------------------------------------------------+*/

/* Set the graphics environment. */
goptions reset=all border device=png;

/* Specify the format catalog to search that has the predefined
   ISO alpha2 code. */
%let originalfmtsearch = %sysfunc(getoption(fmtsearch,keyword));
options fmtsearch=(sashelp.mapfmts);

/* Create a table named demographics using sashelp.demographics
   as the base and changing its variables to match GfK variable
   types and lengths. */
proc sql;
create table demographics(rename=(iso=oiso newiso=iso id=oldid newid=ID)) as
select demo.*, 
put(demo.iso,z3.) as newiso format=$3.,
put(demo.iso,ison2a.) as newid 
from sashelp.demographics as demo
;
alter table demographics
modify ID char(15) label='Alpha2 Country Code';
quit;

/* Define the titles and the footnote for the map. */
title1 "Population Annual Growth Rate Percentage";
title2 "South America (1995-2005)";
footnote1 j=r "This map was drawn using GfK map data.";

/* Produce the surface map. */
proc gmap map=mapsgfk.samerica data=demographics;
id id;
surface popagr / stat=sum;
run;
quit;

/* Reset the graphics environment. */
goptions reset=all;

/* Restore the original FMTSEARCH system option value. */
options &originalfmtsearch;
