 /*+-------------------------------------------------------------+
   |          S A S   S A M P L E   L I B R A R Y                |
   |                                                             |
   |    NAME: GMPCOUNT                                           |
   |   TITLE: GMPCOUNT- Mapping an Individual Country            |
   |                    by Subsetting MAPSSAS.WORLD              |
   | PRODUCT: GRAPH                                              |
   |  SYSTEM: ALL                                                |
   |    KEYS: GRAPHICS MAPS GMAP                                 |
   |   PROCS: GMAP                                               |
   |    DATA: EXTERNAL                                           |
   |                                                             |
   | SUPPORT: GRAPHICS STAFF                                     |
   |  UPDATE: 16JUL2012                                          |
   |     REF: SAS/GRAPH AND BASE SAS MAPPING REFERENCE           |
   +-------------------------------------------------------------+*/

/* Set the graphics environment. */
goptions border;

/* Enable the formats from the SASHELP.MAPFMTS catalog. */
%let originalfmtsearch = %sysfunc(getoption(fmtsearch,keyword));
options insert=(fmtsearch=(sashelp.mapfmts));

/* Subset the MAPSSAS.WORLD map data set for the Bahamas by using
   the SQL procedure and the geographic locator code format
   (GLCNSM). */
proc sql;
 create table mymap as
 select * from mapssas.world
 where put(id,glcnsm.) eq "Bahamas"
 ;
 run;
 
/* Create the map by using the GMAP procedure. */
proc gmap map=mymap data=mymap;
 format id glcnsm.;
 id id;
 choro id / stat=first;
run;
quit;

/* Reset the graphics environment. */
goptions reset=all;

/* Restore the original FMTSEARCH system option value. */
options &originalfmtsearch;
