 /****************************************************************/
 /*          S A S   S A M P L E   L I B R A R Y                 */
 /*                                                              */
 /*    NAME: GPJGDFLT                                            */
 /*   TITLE: GPJGDFLT-Using Default Projection Method            */
 /*          PROCEDURE                                           */
 /* PRODUCT: GRAPH                                               */
 /*  SYSTEM: ALL                                                 */
 /*    PROC: GINSIDE                                             */
 /*    DATA: INTERNAL                                            */
 /*                                                              */
 /* SUPPORT: GRAPHICS STAFF              CREATED: 04AUG2022      */
 /*     REF: SAS/GRAPH AND BASE SAS MAPPING REFERENCE            */
 /****************************************************************/

/* Set the graphics environment */
goptions border;
 
/* Create a reduced continental U.S. map data set and remove
   Alaska, Hawaii, and Puerto Rico. */
data us48unproj;
   set mapsgfk.us_states;
   if state not in (2 15 72);
   drop x y;
   rename long=x lat=y;
run;

/* Define the title for the unprojected map. */
title "United States Map: Unprojected";

/* Define the pattern characteristics. */
pattern value=mempty color=blue;

/* Show the unprojected map. */
proc gmap map=us48unproj data=us48unproj all;
   id state;
   choro state / statistic=first nolegend levels=1;
run;
quit;

/* Project the map data set using the default method. */
proc gproject data=us48unproj out=us48proj degrees eastlong;
   id state;
run;

/* Show the projected map. */
title "United States Map: Albers Eastlong Projection";
proc gmap map=us48proj data=us48proj all density=4;
   id state;
   choro state / statistic=first nolegend levels=1;
run;
quit;

/* Reset the graphics environment. */
goptions reset=all;
