 /****************************************************************/
 /*          S A S   S A M P L E   L I B R A R Y                 */
 /*                                                              */
 /*    NAME: GPJGEMPH                                            */
 /*   TITLE: GPJGEMPH-Emphasizing Map Areas                      */
 /*          PROCEDURE                                           */
 /* PRODUCT: GRAPH                                               */
 /*  SYSTEM: ALL                                                 */
 /*    PROC: GINSIDE                                             */
 /*    DATA: INTERNAL                                            */
 /*                                                              */
 /* SUPPORT: GRAPHICS STAFF              CREATED: 04AUG2022      */
 /*     REF: SAS/GRAPH AND BASE SAS MAPPING REFERENCE            */
 /****************************************************************/

/* Set the graphics environment */
goptions reset=all border device=png;

/* Create a reduced continental U.S. map data set that excludes
   Alaska, Hawaii, and Puerto Rico. */
data us48;
   set mapsgfk.us_states;
   if state not in (2 15 72);
run;

/* Project the map onto a plane centered in the Pacific. */
proc gproject data=us48
              latlon
              degrees eastlong
              out=skew
              project=gnomon
              polelong=200
              polelat=50;
   id state;
run;

/* Define the title and footnote for the map. */
title "United States Map";
footnote1 j=r "This map was drawn using GfK map data.";

/* Define the pattern characteristics. */
pattern value=mempty color=blue;

/* Show the projected map. */
proc gmap map=skew data=skew all;
   id state;
   choro state / statistic=first nolegend levels=1;
run;
quit;

/* Reset the graphics environment. */
goptions reset=all;
