 /*+-------------------------------------------------------------+
   |          S A S   S A M P L E   L I B R A R Y                |
   |                                                             |
   |    NAME: GPJDEFLT                                           |
   |   TITLE: GPJDEFLT-Using Default Projection Specifications   |
   |          with Traditional Map Data                          |
   | PRODUCT: GRAPH                                              |
   |  SYSTEM: ALL                                                |
   |    KEYS: GRAPHICS GOPTIONS GMAP GPROJECT MAPS PATTERN       |
   |   PROCS: GMAP GPROJECT                                      |
   |    DATA: EXTERNAL                                           |
   |                                                             |
   | SUPPORT: GRAPHICS STAFF                                     |
   |  UPDATE: 26JUN2008                                          |
   |     REF: SAS/GRAPH AND BASE SAS MAPPING REFERENCE           |
   +-------------------------------------------------------------+*/

/* Set the graphics environment. */
goptions border;

/* Create a reduced continental U.S. map data set and remove
   Alaska, Hawaii, and Puerto Rico. */
data us48unproj;
   set mapssas.states;
   if state not in (2 15 72);
run;

/* Define the title for the unprojected map. */
title "United States Map: Unprojected";

/* Define the pattern characteristics. */
pattern value=mempty color=blue;

/* Show the unprojected map. */
proc gmap map=us48unproj data=us48unproj all density=4;
   id state;
   choro state / stat=first nolegend levels=1;
run;

/* Project the map data set using all default criteria. */
proc gproject data=us48unproj
              out=us48proj;
   id state;
run;

/* Show the projected map. */
title "United States Map: Albers Eastlong Projection";
proc gmap map=us48proj
          data=us48proj all density=4;
   id state;
   choro state / stat=first nolegend levels=1;
run;
quit;

/* Reset the graphics environment. */
goptions reset=all;
