 /*+-------------------------------------------------------------+
   |          S A S   S A M P L E   L I B R A R Y                |
   |                                                             |
   |    NAME: GPJEMPHS                                           |
   |   TITLE: GPJEMPHS-Emphasizing Map Areas Using Traditional   |
   |          Map Data                                           |
   | PRODUCT: GRAPH                                              |
   |  SYSTEM: ALL                                                |
   |    KEYS: GRAPHICS GOPTIONS GMAP GPROJECT MAPS PATTERN       |
   |   PROCS: GMAP GPROJECT                                      |
   |    DATA: EXTERNAL                                           |
   |                                                             |
   | SUPPORT: GRAPHICS STAFF                                     |
   |  UPDATE: 02NOV2007                                          |
   |     REF: SAS/GRAPH AND BASE SAS MAPPING REFERENCE           |
   +-------------------------------------------------------------+*/

/* Set the graphics environment. */
goptions border;

/* Create a reduced continental U.S. map data set and remove
   Alaska, Hawaii, and Puerto Rico. */
data us48;
   set mapssas.states;
   if state ne 2 and state ne 15 and state ne 72;
   if density<4;
run;

/* Project the map onto a plane centered in the Pacific. */
proc gproject data=us48
              out=skew
              project=gnomon
              polelong=160
              polelat=45;
   id state;
run;

/* Define the title for the map. */
title "United States Map";

/* Define the pattern characteristics. */
pattern value=mempty color=blue;

/* Show the projected map. */
proc gmap map=skew data=skew all;
   id state;
   choro state / statistic=first nolegend levels=1;
run;
quit;

/* Reset the graphics environment. */
goptions reset=all;

