 /****************************************************************/
 /*          S A S   S A M P L E   L I B R A R Y                 */
 /*                                                              */
 /*    NAME: GRMGUSMA                                            */
 /*   TITLE: GRMGUSMA-Removing State Boundaries from U.S. Map    */
 /*          PROCEDURE                                           */
 /* PRODUCT: GRAPH                                               */
 /*  SYSTEM: ALL                                                 */
 /*    PROC: GINSIDE                                             */
 /*    DATA: INTERNAL                                            */
 /*                                                              */
 /* SUPPORT: GRAPHICS STAFF              CREATED: 04AUG2022      */
 /*     REF: SAS/GRAPH AND BASE SAS MAPPING REFERENCE            */
 /****************************************************************/

/* Set the graphics environment */
goptions border;

/* Create data set MYMAP. */
data myMap; 
   set mapsgfk.us;
   original_order=_n_;
run;

/* Create a sorted data set, MYREGIONMAP. */
proc sql noprint;
   create table myRegionMap as
   select myMap.*, us_data.region
   from myMap left join sashelp.us_data
   on myMap.statecode=us_data.statecode
   order by region, statecode, original_order;
run;

/* Remove interior boundaries within regions. */
proc gremove data=myRegionMap out=myRegionMap;
   by region;
   id statecode;
run;

/* Define the title for the map. */
title "U.S. State Map With State Borders";

/* Define the state pattern characteristics. */
pattern value=s color=white;

/* Show the original map. */
proc gmap map=mapsgfk.us data=mapsgfk.us all;
   id state;
   choro segment / stat=first levels=1 nolegend
   des='' name="grmgusmA";
run;
quit;

/* Define the new title for the map with state
   boundaries removed. */
title "U.S. Map With Region Borders";

/* Reset the pattern to use the default color pattern before
   creating the map with state boundaries removed. */
goptions reset=pattern;

/* Show the regional map. */
proc gmap map=myRegionMap data=sashelp.us_data all;
   id region;
   choro region / stat=first cdefault=red
   des='' name="grmgusmB";
run;
quit;

/* Reset the graphics environment. */
goptions reset=all;
