 /*+---------------------------------------------------------------------+
   |          S A S   S A M P L E   L I B R A R Y                        |
   |    NAME: SGMPNVBU                                                   |
   |   TITLE: SGMPNVBU Creating a Map of Nevada Counties with a Bubble   |
   |          Plot of County Seat Populations                            |
   |                                                                     |
   | PRODUCT: BASE                                                       |
   |  SYSTEM: ALL                                                        |
   |    KEYS: GRAPHICS CHOROMAP SGMAP BUBBLE OSM                         |
   |   PROCS: SGMAP                                                      |
   |    DATA: INTERNAL                                                   |
   |                                                                     |
   | SUPPORT: GRAPHICS STAFF                  CREATED: AUG2017           |
   |  UPDATE:  OCT2018                                                   |
   |           NOV2019                                                   |
   |     REF: SAS/GRAPH AND BASE SAS MAPPING REFERENCE                   |
   +---------------------------------------------------------------------+*/

/* Define the graphics environment. */
ods graphics / border;

/* Create county seat population response data set for bubbles. */
data city_pop;
  length city $80;
  infile datalines dlm=',';
  state = 'NV';
  input city population;
datalines;
Fallon, 8458
Las Vegas, 623747
Minden, 3180
Elko, 20279
Goldfield, 443
Eureka, 487
Winnemucca, 7887
Battle Mountain, 3276
Pioche, 911
Yerington, 3064
Hawthorne, 3095
Tonopah, 2360
Lovelock, 1878
Virginia City, 717
Reno, 241445
Ely, 4134
Carson City, 54521
;
run;

/* Determine city locations of the county seats. */
proc geocode method=city
  data=city_pop
  out=city_pop (rename=(x=long y=lat))
  lookupcity=sashelp.zipcode; /* Use this if you don't have SAS GRAPH */
run;

/* Retrieve the Nevada county boundaries for the choropleth map. In
   this MAPSGFK data set, coordinates are in eastlong degrees and the
   character STATECODE variables are available. */
data nevada;
  set mapsgfk.us_counties(where=(statecode='NV'));
run;

/* Generate the title, map, and the legend. */
title 'Nevada County Seat Populations';
proc sgmap mapdata=nevada       /* Map boundaries */
           plotdata=city_pop /* Bubble response & location data */
           des='Nevada';
  openstreetmap;
  choromap / mapid=county lineattrs=(color=blue) legendlabel='Counties';
  bubble x=long y=lat size=population /
     datalabel=city legendlabel='City Population'
     datalabelattrs=(color=darkred size=9 style=italic);
run;
quit;

/* Reset the graphics environment */
ods graphics / reset;
title;
