 /*+---------------------------------------------------------------------+
   |          S A S   S A M P L E   L I B R A R Y                        |
   |    NAME: SGMPGRAD                                                   |
   |   TITLE: SGMPGRAD Adding a Gradient Legend Showing Population Using |
   |          Traditional Map Data                                       |
   |                                                                     |
   | PRODUCT: BASE                                                       |
   |  SYSTEM: ALL                                                        |
   |    KEYS: GRAPHICS CHOROMAP SGMAP GRADLEGEND                         |
   |   PROCS: SGMAP                                                      |
   |    DATA: INTERNAL                                                   |
   | RELEASE: SAS 9.4M7 and prior releases                               |
   |                                                                     |
   | SUPPORT: GRAPHICS STAFF                   CREATED: OCT2018          |
   |     REF: SAS/GRAPH AND BASE SAS MAPPING REFERENCE                   |
   +---------------------------------------------------------------------+*/

/* Define the graphics environment. */
ods graphics / border outputfmt=png;

/* The CHOROMAP statement plots the X (longitude) and Y (latitude)
   variables from the MAPS data set that contains unprojected latitude and
   longitude values. */
data states;
  set mapssas.states;
  if state ^in(2,15,72);
  x = -x * 45/atan(1); 
  y =  y * 45/atan(1);
run;

/* Create the plot data, used by the SGMAP procedure statement and the
   TEXT statement. */
data plot_data; 
set mapssas.uscenter;
  if state ^in(2,15,72) and ocean^='Y';
  long = -long;
  statename = fipstate(state);
run;

/* Assign a title to the graph. */
title 'Population from 2010 US Census';

/* Create the graph. */
proc sgmap mapdata=states
  maprespdata=sashelp.us_data
  plotdata=plot_data;

  esrimap
  url='https://services.arcgisonline.com/arcgis/rest/services/
Canvas/World_Light_Gray_Base';

  choromap population_2010 / mapid=state density=2
    name='choro';

  text x=long y=lat text=statename /
    textattrs=(size=6pt);

  gradlegend 'choro' / title='2010 Population' 
	   extractscale;

run;
quit;

/* Reset the graphics environment */
ods graphics / reset;
title;
